"""
xkcd API Wrapper
~~~~~~~~~~~~~~~~~~~

A basic API wrapper for xkcd.

:copyright: (c) 2022 Omkaar
:license: MIT, see LICENSE for more details.
"""


__title__ = "xkcd.py"
__author__ = "Infiniticity"
__license__ = "MIT"
__copyright__ = "Copyright 2022 Omkaar"
__version__ = "1.0.4"


from .comic import Comic
from .what_if import WhatIfArticle
